


<h1 align="center">Saavn</h1>
<p align="center">Unofficial JioSaavn API Client for python </p>


<div align="center">
<img src="https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54">
<img src="https://img.shields.io/badge/iohttp-%232C5bb4.svg?style=for-the-badge&logo=aiohttp&logoColor=white">
</div>